summaryrefslogtreecommitdiff
path: root/libdiskfs
diff options
context:
space:
mode:
authorRoland McGrath <roland@gnu.org>1994-09-10 16:21:30 +0000
committerRoland McGrath <roland@gnu.org>1994-09-10 16:21:30 +0000
commit70490907fdba820987f269a5617de7dbbbb765f0 (patch)
treea47765956d23a917071a5e436b229635d6b019d8 /libdiskfs
parent0a26b0b62320d968ab0ec74372ac97281a218e21 (diff)
Formerly diskfs.h.~35~
Diffstat (limited to 'libdiskfs')
-rw-r--r--libdiskfs/diskfs.h15
1 files changed, 10 insertions, 5 deletions
diff --git a/libdiskfs/diskfs.h b/libdiskfs/diskfs.h
index 0f1d372d..efe3c1f9 100644
--- a/libdiskfs/diskfs.h
+++ b/libdiskfs/diskfs.h
@@ -461,11 +461,16 @@ error_t (*diskfs_read_symlink_hook)(struct node *np, char *target);
returned. */
char *diskfs_parse_bootargs (int argc, char **argv);
-/* Call this after arguments have been parsed to initialize the
- library. If BOOTSTRAP is set, the diskfs will call fsys_startup
- on that port as appropriate and return the REALNODE returned
- in that call; otherwise we return MACH_PORT_NULL. */
-mach_port_t diskfs_init_diskfs (mach_port_t bootstrap);
+/* Call this after arguments have been parsed to initialize the library.
+ You must call this before calling any other diskfs functions except
+ for diskfs_parse_bootargs. */
+void diskfs_init_diskfs (void);
+
+/* Call this once the filesystem is fully initialized, to advertise the new
+ filesystem control port to our parent filesystem. If BOOTSTRAP is set,
+ the diskfs will call fsys_startup on that port as appropriate and return
+ the REALNODE returned in that call; otherwise we return MACH_PORT_NULL. */
+mach_port_t diskfs_startup_diskfs (mach_port_t bootstrap);
/* Call this after all format-specific initialization is done (except
for setting diskfs_root_node); at this point the pagers should be